FocusedBorderStyle class

A style definition for FocusedBorder.

Constructors

FocusedBorderStyle({double thickness = 2.0, Color color = Colors.blue, BorderRadius headerBorderRadius = const BorderRadius.all(Radius.circular(80)), BorderRadius daysBorderRadius = const BorderRadius.all(Radius.circular(8))})
const

Properties

color Color
Color of the focus border.
final
daysBorderRadius BorderRadius
Radius of the focus border corners for the days.
final
hashCode int
The hash code for this object.
no setterinherited
headerBorderRadius BorderRadius
Radius of the focus border corners for the header.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thickness double
Thickness of the focus border.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited